Quickstart
===========================================

.. raw:: html

    <script src="https://gist.github.com/semiautomaticgit/cd52dba7effc1d105f1883408710ff08.js"></script>

Link to the guide:
https://colab.research.google.com/gist/semiautomaticgit/cd52dba7effc1d105f1883408710ff08/quickstart.ipynb
